/******************Introductory Note*************************/

/*This application partly replicates Disdier, Fontagn and Mimoui (2008) but using more recent data. 
It focuses on agri-food products (HS chapters 01 to 24) and investigates the trade effects of SPS and TBTs 
on the exports of 189 countries to 23 OECD partners (20 European countries, Chile, Japan and Mexico) in 2012. 
The empirical application consists in the estimation of a gravity equation as described in module 3.
The database "dataset_final.dta" is available on the UNCTAD course website and already includes the variables needed for the estimations. 
As in previous application the NTM data come from the CEPII website and are based on the TNT database. 
The trade data are extracted from the BACI database also provided by the CEPII. 
Other gravity variables, such as distance, contiguity, common language and past colonial links are also from the CEPII. 
Exporting and importing countries size is proxied by the gross domestic product taken from the World Development Indicators database. 
Finally, we also control for the bilateral applied protection using tariff data retrieved from the using 
the MAcMap version of the UNCTAD/TRAINS database. 
The database is built at the Harmonized System Classification 4-digit level and two variables account for NTMs:
-	A simple dummy variable set to 1 if the importing country notifies at least one SPS/TBT measure on one HS 6-digit 
product within the HS 4-digit sector (0 otherwise);
-	A frequency index computed for each importing country and HS 4-digit sector and defined as the number of HS 6-digit lines affected 
by at least one SPS/TBT measure divided 
by the total number of HS6 lines within the HS 4-digit sector.
Note that the bilateral tariffs at the HS 4-digit level are computed as the simple mean of applied tariffs for all HS 6-digit lines 
within the HS4 sector and for each country-pair. 
Tariffs are for the year 2010. Finally, exporting countries are divided into two groups (OECD versus developing exporters), 
and intra-European trade flows are dropped from the sample 
to avoid biases (within the European Union, tariffs are set to zero and the mutual recognition is applied for NTMs). */

/**********Preliminary Manipulations **********/

*The first step consists in opening the data into STATA and finalizing the dataset.

/*Before opening the dataset you may want to change the default directory that is the directory STATA will use unless another directory is specified. We created a folder called STATA_NTM (c:/ STATA_NTM) and copied all files that are needed to run the application (data files and do-files) into that folder. To change the default directory just run*/

cd c:/STATA_NTM/Application2

/*To open the dataset in STATA, the command use should be applied. Before running the estimations, we add some labels to the variables with the label var command. */

*Labels are self-explanatory.

/*If you want to save the output of your session you must open a so-called log file */
log using application_2.log, replace /*it is in a text format*/


use dataset_final.dta, clear

/* If you had not changed the default directory the right command would be */
* use c:/ STATA_NTM/dataset_final.dta, clear

label var lgdp_o "log GDP exporter"
label var lgdp_d "log GDP importer"
label var ldist "log distance"
label var mtariffs "mean bilateral tariffs (HS4, simple average)"
label var dum_spstbt_jk "= 1 if at least 1 SPS/TBT at the importer-HS6 level"
label var freq_spstbt_jk "frequency index for SPS/TBT by importer"
label var contig "common border"
label var comlang_ethno "common language (spoken by at least 9% of the pop in both countries"
label var colony "colonial links"
label var hs2 "HS 2-digit code"
label var hs4 "HS 4-digit code"
label var imp_hs2 "Importer-HS2 fixed effects"
label var exp_hs2 "Exporter-HS2 fixed effects"
label var imp_hs4 "bilateral HS4 imports"
label var limphs4 "log of bilateral HS4 imports"
label var oecd_d "=1 if importer is an OECD country"
label var oecd_o "=1 if exporter is an OECD country"
label var dc_o "=1 if exporter is a developing country"
label var eur_o "=1 if exporter is an EU country"
label var eur_d "=1 if importer is an EU country"
describe


/***********Run first some basic estimations**********/

* Estimation #1: control only for tariffs but not for NTMs
xi: areg limphs4 lgdp_o lgdp_d ldist contig comlang_ethno colony mtariffs, absorb(hs2) cluster(groupbil) robust

* Estimation #2: control for tariffs and include a dummy for SPS/TBTs
xi: areg limphs4 lgdp_o lgdp_d ldist contig comlang_ethno colony mtariffs dum_spstbt_jk, absorb(hs2) cluster(groupbil) robust

* Estimation #3: control for tariffs and include a frequency index for SPS/TBTs
xi: areg limphs4 lgdp_o lgdp_d ldist contig comlang_ethno colony mtariffs freq_spstbt_jk, absorb(hs2) cluster(groupbil) robust

* Estimation #4: focus on European imports and include a dummy for SPS/TBTs
xi: areg limphs4 lgdp_o lgdp_d ldist contig comlang_ethno colony mtariffs dum_spstbt_jk if eur_d == 1, absorb(hs2) cluster(groupbil) robust

* Estimation #5: focus on European imports and include a frequency index for SPS/TBTs
xi: areg limphs4 lgdp_o lgdp_d ldist contig comlang_ethno colony mtariffs freq_spstbt_jk if eur_d == 1, absorb(hs2) cluster(groupbil) robust

/*********Run fixed effect estimations****************/

*We now replace countries gross domestic products by two sets of fixed effects: one for the exporter and one for the importer (see Box 1). 
*These fixed effects are interacted with HS 2-digit fixed effects. We replicate the previous set of regressions. 

* Estimation #6: control only for tariffs but not for NTMs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtariffs, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

* Estimation #7: control for tariffs and include a dummy for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtariffs dum_spstbt_jk, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

* Estimation #8: control for tariffs and include a frequency index for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtariffs freq_spstbt_jk, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

* Estimation #9: focus on European imports and include a dummy for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtariffs dum_spstbt_jk if eur_d == 1, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

* Estimation #10: focus on European imports and include a frequency index for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtariffs freq_spstbt_jk if eur_d == 1, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

/***********Run fixed effect estimations, by group of exporters******************/

*As in Disdier, Fontagn and Mimouni (2008), we now examine the potential difference in the trade impact of tariffs and NTMs across exporters. 
*To do so, we interact the tariff and NTM variables with the two dummies identifying OECD and developing exporters. 
* Interaction terms between tariff and sps/tbt variables and groups of exporters

gen mtar_oecd = mtariffs * oecd_o
gen mtar_dc = mtariffs * dc_o
gen dumntm_oecd = dum_spstbt_jk * oecd_o
gen dumntm_dc = dum_spstbt_jk * dc_o
gen freqntm_oecd = freq_spstbt_jk * oecd_o
gen freqntm_dc = freq_spstbt_jk * dc_o

* Estimation #11: control for tariffs and include a dummy for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtar_oecd mtar_dc dumntm_oecd dumntm_dc, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

* Estimation #12: control for tariffs and include a frequency index for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtar_oecd mtar_dc freqntm_oecd freqntm_dc, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

* Estimation #13: focus on European imports and include a dummy for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtar_oecd mtar_dc dumntm_oecd dumntm_dc if eur_d == 1, id1(imp_hs2) id2(exp_hs2) cluster(groupbil) 

* Estimation #14: focus on European imports and include a frequency index for SPS/TBTs
reg2hdfe limphs4 ldist contig comlang_ethno colony mtar_oecd mtar_dc freqntm_oecd freqntm_dc if eur_d == 1, id1(imp_hs2) id2(exp_hs2) cluster(groupbil)  

/* you must close your log file at the end of the session*/
log close
